# Project Authors

The following people have made contributions to the project (in alphabetical
order by last name) and are considered "The Harmonica Developers":

* [Vanderlei C Oliveira Jr](https://github.com/birocoles) - Observatório Nacional, Brazil (ORCID: 0000-0002-6338-4086)
* [Agustina Pesce](https://github.com/aguspesce) - Universidad Nacional de San Juan, Argentina (ORCID: 0000-0002-5538-8845)
* [Nicholas Shea](https://github.com/nshea3) - MINES ParisTech (ORCID: 0000-0001-6007-5686)
* [Santiago Soler](https://github.com/santisoler) - CONICET, Argentina; Instituto Geofísico Sismológico Volponi, Universidad Nacional de San Juan, Argentina (ORCID: 0000-0001-9202-5317)
* [Leonardo Uieda](https://github.com/leouieda) - University of Liverpool, UK (ORCID: 0000-0001-6123-9515)
* [ziebam](https://github.com/ziebam) (not included in Zenodo)
